==> rospell-2007.02.rc1.tar.gz: rospell-2007.02.rc1/src/rospell/qtutils.cpp <==
//****************************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//****************************************************************************

#include "global.h"
#include "qtutils.h"
#include <qregexp.h>

void QTUTILS::run_program(QString program, Q3MultiLineEdit *wdg, char *termination_string) {
	PROFILE("QT_UTILS::run_program");
	FILE *input;
	char buf[PROG_BUF + 1];
	char *out;

	if (0 == (input = popen(program, "r")))
		return;

	else {
		while ((out = fgets(buf, PROG_BUF, input)) != 0) {
			printf("%s", buf);
			LOG("QT_UTILS::run_program: len %d", strlen(buf));
			wdg->insertLine(QString::fromUtf8(buf));
			wdg->update();
			qApp->processEvents();
		}

		pclose(input);
	}

	if (termination_string)
		wdg->insertLine(QString(termination_string));

}

// suplimenting QString::find with whole word flag
int QTUTILS::find(QString &haystack, QString &needle, int index, bool cs, bool whole) {
	int retval = haystack.find(needle, index, cs);
	if (retval == -1)
		return -1;

	if (whole) {
		int xstart = retval;
		while (xstart >= 0 && (haystack.at(xstart).isLetterOrNumber() || haystack.at(xstart) == '_'))
			xstart--;
		if (xstart != 0)
			xstart++;

		int xend = retval;
		while (haystack.at(xend).isLetterOrNumber() || haystack.at(xend) == '_')
			xend++;
		QString found = haystack.mid(xstart, xend - xstart);
		if (found == needle)
			return retval;
		else
			return QTUTILS::find(haystack, needle, retval + 1, cs, whole);
	}
	return retval;
}

// suplimenting QString::findRev with whole word flag
int QTUTILS::findRev(QString &haystack, QString &needle, int index, bool cs, bool whole) {
//printf("%d %s/%s\n", index, (const char *) haystack, (const char *) needle);
	int retval = haystack.findRev(needle, index, cs);
//printf("retval %d\n", retval);
	if (retval == -1)
		return -1;

	if (whole) {
		int xstart = retval;
		while (xstart >= 0 && (haystack.at(xstart).isLetterOrNumber() || haystack.at(xstart) == '_'))
			xstart--;
		if (xstart != 0)
			xstart++;

		int xend = retval;
		while (haystack.at(xend).isLetterOrNumber() || haystack.at(xend) == '_')
			xend++;
		QString found = haystack.mid(xstart, xend - xstart);
		if (found == needle)
			return retval;
		else
			return QTUTILS::findRev(haystack, needle, retval - 1, cs, whole);
	}
	return retval;
}

QString QTUTILS::stripTrailingSpaces(QString &input) {
	return input.replace(QRegExp("[ \t]+\n"), "\n");
}

QString QTUTILS::unixEol(QString &input) {
	QString tmp = input.replace(QRegExp("\n\r"), "\n");
	return input.replace(QRegExp("\r\n"), "\n");
}

QString QTUTILS::cedilla2commabelow(QString &input) {
	QString tmp = input.replace(QRegExp(QString::fromUtf8("ş")), QString::fromUtf8("ș"));
	tmp = tmp.replace(QRegExp(QString::fromUtf8("Ş")), QString::fromUtf8("Ș"));
	tmp = tmp.replace(QRegExp(QString::fromUtf8("ţ")), QString::fromUtf8("ț"));
	tmp = tmp.replace(QRegExp(QString::fromUtf8("Ţ")), QString::fromUtf8("Ț"));
	return tmp;
}

QString QTUTILS::commabelow2cedilla(QString &input) {
	QString tmp = input.replace(QRegExp(QString::fromUtf8("ș")), QString::fromUtf8("ş"));
	tmp = tmp.replace(QRegExp(QString::fromUtf8("Ș")), QString::fromUtf8("Ş"));
	tmp = tmp.replace(QRegExp(QString::fromUtf8("ț")), QString::fromUtf8("ţ"));
	tmp = tmp.replace(QRegExp(QString::fromUtf8("Ț")), QString::fromUtf8("Ţ"));
	return tmp;
}

==> rospell-2009.00-rc2.tar.gz: rospell-2009.00-rc2/src/rospell/qtutils.cpp <==
//****************************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//****************************************************************************

#include "global.h"
#include "qtutils.h"
#include <qregexp.h>
#ifdef USING_QT4
#include <Q3CString>
#endif

void QTUTILS::run_program(QString program, Q3MultiLineEdit *wdg, char *termination_string) {
	PROFILE("QT_UTILS::run_program");
	FILE *input;
	char buf[PROG_BUF + 1];
	char *out;

	if (0 == (input = popen(program, "r")))
		return;

	else {
		while ((out = fgets(buf, PROG_BUF, input)) != 0) {
			printf("%s", buf);
			LOG("QT_UTILS::run_program: len %d", strlen(buf));
			wdg->insertLine(QString::fromUtf8(buf));
			wdg->update();
			qApp->processEvents();
		}

		pclose(input);
	}

	if (termination_string)
		wdg->insertLine(QString(termination_string));

}

// suplimenting QString::find with whole word flag
int QTUTILS::find(QString &haystack, QString &needle, int index, bool cs, bool whole) {
	int retval = haystack.find(needle, index, cs);
	if (retval == -1)
		return -1;

	if (whole) {
		int xstart = retval;
		while (xstart >= 0 && (haystack.at(xstart).isLetterOrNumber() || haystack.at(xstart) == '_'))
			xstart--;
		if (xstart != 0)
			xstart++;

		int xend = retval;
		while (haystack.at(xend).isLetterOrNumber() || haystack.at(xend) == '_')
			xend++;
		QString found = haystack.mid(xstart, xend - xstart);
		if (found == needle)
			return retval;
		else
			return QTUTILS::find(haystack, needle, retval + 1, cs, whole);
	}
	return retval;
}

// suplimenting QString::findRev with whole word flag
int QTUTILS::findRev(QString &haystack, QString &needle, int index, bool cs, bool whole) {
//printf("%d %s/%s\n", index, (const char *) haystack, (const char *) needle);
	int retval = haystack.findRev(needle, index, cs);
//printf("retval %d\n", retval);
	if (retval == -1)
		return -1;

	if (whole) {
		int xstart = retval;
		while (xstart >= 0 && (haystack.at(xstart).isLetterOrNumber() || haystack.at(xstart) == '_'))
			xstart--;
		if (xstart != 0)
			xstart++;

		int xend = retval;
		while (haystack.at(xend).isLetterOrNumber() || haystack.at(xend) == '_')
			xend++;
		QString found = haystack.mid(xstart, xend - xstart);
		if (found == needle)
			return retval;
		else
			return QTUTILS::findRev(haystack, needle, retval - 1, cs, whole);
	}
	return retval;
}

QString QTUTILS::stripTrailingSpaces(QString &input) {
	return input.replace(QRegExp("[ \t]+\n"), "\n");
}

QString QTUTILS::unixEol(QString &input) {
	QString tmp = input.replace(QRegExp("\n\r"), "\n");
	return tmp.replace(QRegExp("\r\n"), "\n");
}

unsigned short QTUTILS::getBookmarker(int bookmark) {
	unsigned short mark = (unsigned short) BOOKMARKER;
	if (bookmark == 0)
		mark += 9;
	else
		mark += bookmark - 1;
	return mark;
}

bool QTUTILS::hasBookmarkers(QString &input) {
	Q3CString utext = input.utf8();
	const char *ctext = utext;
	unsigned char *ptr = (unsigned char *) ctext;

	while (*ptr != '\0') {
		if (*ptr != 0xe2 || *(ptr + 1) != 0x9e) {
			ptr++;
			continue;
		}
		ptr += 2;
		if (*ptr >= 0x8a && *ptr <= 0x93)
			return true;
	}
	return false;
}

// look for bookmarkers in the middle of the string
bool QTUTILS::hasBadBookmarkers(QString &input) {
	Q3CString utext = input.utf8();
	const char *ctext = utext;
	unsigned char *ptr = (unsigned char *) ctext;
	bool start = true;
	
	while (*ptr != '\0') {
		if (*ptr != 0xe2 || *(ptr + 1) != 0x9e) {
			ptr++;
			start = false;
			continue;
		}
		ptr += 2;
		if (*ptr >= 0x8a && *ptr <= 0x93) {
			if (!start)
				return true;
		}
	}
	return false;
}

bool QTUTILS::startsWithBookmarker(QString &input) {
	Q3CString utext = input.utf8();
	const char *ctext = utext;
	unsigned char *ptr = (unsigned char *) ctext;

	if (*ptr == 0xe2 && *(ptr + 1) == 0x9e) {
		ptr += 2;
		if (*ptr == '\0')
			return false;

		if (*ptr >= 0x8a && *ptr <= 0x93)
			return true;
	}
	return false;
}

QString QTUTILS::cleanBookmarkers(QString &input) {
	unsigned short i;
	for (i = 0; i < 10; i++) {
		QString bookstr = QChar((unsigned short) BOOKMARKER + i);
		input = input.replace(QRegExp(bookstr), "");
	}
	return input;
}

QString QTUTILS::cleanBookmarker(QString &input, int bookmark) {
	unsigned short bookmarker = QTUTILS::getBookmarker(bookmark);
	QString bookstr = QChar(bookmarker);
	return input.replace(QRegExp(bookstr), "");
}

QString QTUTILS::cedilla2commabelow(QString &input) {
	QString tmp = input.replace(QRegExp(QString::fromUtf8("ş")), QString::fromUtf8("ș"));
	tmp = tmp.replace(QRegExp(QString::fromUtf8("Ş")), QString::fromUtf8("Ș"));
	tmp = tmp.replace(QRegExp(QString::fromUtf8("ţ")), QString::fromUtf8("ț"));
	tmp = tmp.replace(QRegExp(QString::fromUtf8("Ţ")), QString::fromUtf8("Ț"));
	return tmp;
}

QString QTUTILS::commabelow2cedilla(QString &input) {
	QString tmp = input.replace(QRegExp(QString::fromUtf8("ș")), QString::fromUtf8("ş"));
	tmp = tmp.replace(QRegExp(QString::fromUtf8("Ș")), QString::fromUtf8("Ş"));
	tmp = tmp.replace(QRegExp(QString::fromUtf8("ț")), QString::fromUtf8("ţ"));
	tmp = tmp.replace(QRegExp(QString::fromUtf8("Ț")), QString::fromUtf8("Ţ"));
	return tmp;
}

QString QTUTILS::tab2space(QString &input) {
	QString tmp = input.replace(QRegExp(QString::fromUtf8("\t")), QString::fromUtf8("        "));
	return tmp;
}
